@@ -1,6 +1,6 @@
 """Simple eCharts API."""
 
-__version__ = "0.3.5"
+__version__ = "0.6.7"
 
 import argparse
 import importlib
@@ -11,8 +11,10 @@ from ezcharts.plots.axisgrid import *  # noqa: F401,F403
 from ezcharts.plots.categorical import *  # noqa: F401,F403
 from ezcharts.plots.distribution import *  # noqa: F401,F403
 from ezcharts.plots.matrix import *  # noqa: F401,F403
+from ezcharts.plots.metagenomics_sankey import *  # noqa: F401,F403
 from ezcharts.plots.regression import *  # noqa: F401,F403
 from ezcharts.plots.relational import *  # noqa: F401,F403
+from ezcharts.plots.sunburst import *  # noqa: F401,F403
 
 
 def cli():
@@ -32,7 +34,10 @@ def cli():
     subparsers.required = True
 
     # all component demos, plus some others
-    components = ['params', 'nextclade', 'fastcat']
+    components = [
+        'params', 'nextclade', 'fastcat', 'dss',
+        'modkit', 'mosdepth', 'clinvar', 'bcfstats'
+        ]
     others = ['ezcharts.demo', 'ezcharts.plots', 'ezcharts.plots.ideogram']
 
     demos = [f'ezcharts.components.{comp}' for comp in components] + others
