@@ -1,14 +1,18 @@
 """Useful reusable functions."""
+import contextlib
 import json
 import os
 from typing import Dict
+import warnings
 
 from dominate.tags import script, style
-from dominate.util import raw, text
+from dominate.util import container, raw, text
 from jinja2 import BaseLoader, Environment
 from pkg_resources import resource_filename
 import sass
 
+warnings.simplefilter("always", DeprecationWarning)
+
 
 def load_json(
     path: str
@@ -76,3 +80,27 @@ def cls(*classes: str) -> str:
 def css(*styles: str) -> str:
     """Collect inline element styles from a list."""
     return ' '.join(s.strip(';') + ';' for s in styles)
+
+
+@contextlib.contextmanager
+def isolate_context():
+    """Prevents `dominate` from adding tags to the enclosing context.
+
+    Some ezCharts `Snippets` use dominate context managers in their constructors.
+    Therefore, they are automatically added to the enclosing `dominate` context when
+    created, which can be undesired in some cases and can be prevented with this
+    function.
+    """
+    warnings.warn(
+        "`layout.util.isolate_context()` will become redundant (and subsequently "
+        "removed) once `ezCharts` makes the switch to use `dominate`s declarative "
+        "syntax for the report components.",
+        DeprecationWarning,
+        stacklevel=3,
+    )
+    # `dominate.util.container` is a tag which can contain elements, but does not add an
+    # extra level
+    with container() as c:
+        yield
+    # remove everything that has been added to `c`
+    c.clear()
