@@ -2,12 +2,13 @@
 
 import argparse
 
-import numpy as np
+from bokeh.plotting import figure
 import pandas as pd
 from pkg_resources import resource_filename
 import sigfig
 
 from ezcharts import util as ezutil
+from ezcharts.components.bokehchart import BokehChart
 from ezcharts.components.ezchart import EZChart
 from ezcharts.components.reports.comp import ComponentReport
 from ezcharts.plots import util
@@ -24,7 +25,7 @@ _logger = ezutil.get_named_logger("Plotter")
 class AxisLabelFormatter(JSCode):
     """Formatter for echarts axis labels."""
 
-    def __init__(self, sci_notation=(0.0001, 10000)):
+    def __init__(self, sci_notation=(0.001, 10000)):
         """Init.
 
         :param: sci_notation:
@@ -64,12 +65,12 @@ class AxisLabelFormatter(JSCode):
             elif self.sci_notation is False:
                 use_sci = False
             else:
-                # If any values fall outside the limits, covert all to sci_notation.
-                # Do not include zeros as they are always plotted as '0'.
+                # If the value with the largest magnitude (in other words, the largest
+                # positive or negative value or value furthest from zero) falls outside
+                # the limits, convert all to sci_notation.
                 sci_limits = self.sci_notation
-                v = np.array(values)
-                v = v[v != 0]
-                if ((v < sci_limits[0]) | (v > sci_limits[1])).any():
+                v = max(abs(min(values)), max(values))
+                if v < sci_limits[0] or v > sci_limits[1]:
                     use_sci = True
                 else:
                     use_sci = False
@@ -233,6 +234,50 @@ class _HistogramPlot(Plot):
         return [self.xAxis, 1], [self.yAxis, 2]
 
 
+class BokehPlot:
+    """Plotting interface for Bokeh."""
+
+    colors = util.choose_palette()
+    tools = "hover,crosshair,pan,box_zoom,zoom_in,zoom_out,reset,save"
+
+    def __init__(self, *args, **kwargs):
+        """Initialize a bokeh figure."""
+        defaults = dict(
+            output_backend="webgl",
+            tools=self.tools,
+            height=300,
+            width=600,
+        )
+        defaults.update(kwargs)
+        self._fig = figure(*args, **defaults)
+        # remove Bokeh logo
+        self._fig.toolbar.logo = None
+
+    @property
+    def logger(self):
+        """Return logger for class."""
+        return _logger
+
+    def render_html(self, output, **kwargs):
+        """Render plot to a file.
+
+        :params output: output file.
+        :param kwargs: passed to `BokehChart`.
+        """
+        title = self._fig.title.text or "Bokeh Plot"
+        chart = BokehChart(self, "epi2melabs", **kwargs)
+        report = ComponentReport(title, chart)
+        report.write(output)
+
+
+class _NoAxisFixPlot(Plot):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def fix_axis_labels(self):
+        self.logger.warning("Skipping axis label fixing")
+
+
 def main(args):
     """Entry point to demonstrate an ezChart."""
     plt = Plot.parse_file(args.plot_spec)
